from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, Int, File, Directory, String

Nosetests_2_7_V0_1_0 = CommandToolBuilder(tool="nosetests_2.7", base_command=["nosetests-2.7"], inputs=[ToolInput(tag="in_plugins", input_type=Boolean(optional=True), prefix="--plugins", doc=InputDocumentation(doc="Output list of available plugins and exit. Combine\nwith higher verbosity for greater detail")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="Be more verbose. [NOSE_VERBOSE]")), ToolInput(tag="in_verbosity", input_type=Int(optional=True), prefix="--verbosity", doc=InputDocumentation(doc="Set verbosity; --verbosity=2 is the same as -v")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Be less verbose")), ToolInput(tag="in_config", input_type=File(optional=True), prefix="--config", doc=InputDocumentation(doc="Load configuration from config file(s). May be\nspecified multiple times; in that case, all config\nfiles will be loaded and combined")), ToolInput(tag="in_where", input_type=Directory(optional=True), prefix="--where", doc=InputDocumentation(doc="Look for tests in this directory. May be specified\nmultiple times. The first directory passed will be\nused as the working directory, in place of the current\nworking directory, which is the default. Others will\nbe added to the list of tests to execute. [NOSE_WHERE]")), ToolInput(tag="in_py_three_where", input_type=Int(optional=True), prefix="--py3where", doc=InputDocumentation(doc="Look for tests in this directory under Python 3.x.\nFunctions the same as 'where', but only applies if\nrunning under Python 3.x or above.  Note that, if\npresent under 3.x, this option completely replaces any\ndirectories specified with 'where', so the 'where'\noption becomes ineffective. [NOSE_PY3WHERE]")), ToolInput(tag="in_test_match", input_type=String(optional=True), prefix="--testmatch", doc=InputDocumentation(doc="Files, directories, function names, and class names\nthat match this regular expression are considered\ntests.  Default: (?:^|[\b_\./-])[Tt]est\n[NOSE_TESTMATCH]")), ToolInput(tag="in_tests", input_type=String(optional=True), prefix="--tests", doc=InputDocumentation(doc="Run these tests (comma-separated list). This argument\nis useful mainly from configuration files; on the\ncommand line, just pass the tests to run as additional\narguments with no switch.")), ToolInput(tag="in_debug", input_type=String(optional=True), prefix="--debug", doc=InputDocumentation(doc="Activate debug logging for one or more systems.\nAvailable debug loggers: nose, nose.importer,\nnose.inspector, nose.plugins, nose.result and\nnose.selector. Separate multiple names with a comma.")), ToolInput(tag="in_debug_log", input_type=File(optional=True), prefix="--debug-log", doc=InputDocumentation(doc="Log debug messages to this file (default: sys.stderr)")), ToolInput(tag="in_logging_config", input_type=File(optional=True), prefix="--logging-config", doc=InputDocumentation(doc="Load logging config from this file -- bypasses all\nother logging config settings.")), ToolInput(tag="in_ignore_files", input_type=File(optional=True), prefix="--ignore-files", doc=InputDocumentation(doc="Completely ignore any file that matches this regular\nexpression. Takes precedence over any other settings\nor plugins. Specifying this option will replace the\ndefault setting. Specify this option multiple times to\nadd more regular expressions [NOSE_IGNORE_FILES]")), ToolInput(tag="in_exclude", input_type=String(optional=True), prefix="--exclude", doc=InputDocumentation(doc="Don't run tests that match regular expression\n[NOSE_EXCLUDE]")), ToolInput(tag="in_include", input_type=String(optional=True), prefix="--include", doc=InputDocumentation(doc="This regular expression will be applied to files,\ndirectories, function names, and class names for a\nchance to include additional tests that do not match\nTESTMATCH.  Specify this option multiple times to add\nmore regular expressions [NOSE_INCLUDE]")), ToolInput(tag="in_stop", input_type=Boolean(optional=True), prefix="--stop", doc=InputDocumentation(doc="Stop running tests after the first error or failure")), ToolInput(tag="in_no_path_adjustment", input_type=Boolean(optional=True), prefix="--no-path-adjustment", doc=InputDocumentation(doc="Don't make any changes to sys.path when loading tests\n[NOSE_NOPATH]")), ToolInput(tag="in_exe", input_type=Boolean(optional=True), prefix="--exe", doc=InputDocumentation(doc="Look for tests in python modules that are executable.\nNormal behavior is to exclude executable modules,\nsince they may not be import-safe [NOSE_INCLUDE_EXE]")), ToolInput(tag="in_no_exe", input_type=Boolean(optional=True), prefix="--noexe", doc=InputDocumentation(doc="DO NOT look for tests in python modules that are\nexecutable. (The default on the windows platform is to\ndo so.)")), ToolInput(tag="in_traverse_namespace", input_type=Boolean(optional=True), prefix="--traverse-namespace", doc=InputDocumentation(doc="Traverse through all path entries of a namespace")), ToolInput(tag="in_attr", input_type=String(optional=True), prefix="--attr", doc=InputDocumentation(doc="Run only tests that have attributes specified by ATTR\n[NOSE_ATTR]")), ToolInput(tag="in_eval_attr", input_type=String(optional=True), prefix="--eval-attr", doc=InputDocumentation(doc="Run only tests for whose attributes the Python\nexpression EXPR evaluates to True [NOSE_EVAL_ATTR]")), ToolInput(tag="in_no_capture", input_type=Boolean(optional=True), prefix="--nocapture", doc=InputDocumentation(doc="Don't capture stdout (any stdout output will be\nprinted immediately) [NOSE_NOCAPTURE]")), ToolInput(tag="in_no_log_capture", input_type=Boolean(optional=True), prefix="--nologcapture", doc=InputDocumentation(doc="Disable logging capture plugin. Logging configuration\nwill be left intact. [NOSE_NOLOGCAPTURE]")), ToolInput(tag="in_logging_format", input_type=String(optional=True), prefix="--logging-format", doc=InputDocumentation(doc="Specify custom format to print statements. Uses the\nsame format as used by standard logging handlers.\n[NOSE_LOGFORMAT]")), ToolInput(tag="in_logging_date_fmt", input_type=String(optional=True), prefix="--logging-datefmt", doc=InputDocumentation(doc="Specify custom date/time format to print statements.\nUses the same format as used by standard logging\nhandlers. [NOSE_LOGDATEFMT]")), ToolInput(tag="in_logging_filter", input_type=String(optional=True), prefix="--logging-filter", doc=InputDocumentation(doc="Specify which statements to filter in/out. By default,\neverything is captured. If the output is too verbose,\nuse this option to filter out needless output.\nExample: filter=foo will capture statements issued\nONLY to  foo or foo.what.ever.sub but not foobar or\nother logger. Specify multiple loggers with comma:\nfilter=foo,bar,baz. If any logger name is prefixed\nwith a minus, eg filter=-foo, it will be excluded\nrather than included. Default: exclude logging\nmessages from nose itself (-nose). [NOSE_LOGFILTER]")), ToolInput(tag="in_logging_clear_handlers", input_type=Boolean(optional=True), prefix="--logging-clear-handlers", doc=InputDocumentation(doc="Clear all other logging handlers")), ToolInput(tag="in_logging_level", input_type=String(optional=True), prefix="--logging-level", doc=InputDocumentation(doc="Set the log level to capture")), ToolInput(tag="in_with_coverage", input_type=Boolean(optional=True), prefix="--with-coverage", doc=InputDocumentation(doc="Enable plugin Coverage:  Activate a coverage report\nusing Ned Batchelder's coverage module.\n[NOSE_WITH_COVERAGE]")), ToolInput(tag="in_cover_package", input_type=String(optional=True), prefix="--cover-package", doc=InputDocumentation(doc="Restrict coverage output to selected packages\n[NOSE_COVER_PACKAGE]")), ToolInput(tag="in_cover_erase", input_type=Boolean(optional=True), prefix="--cover-erase", doc=InputDocumentation(doc="Erase previously collected coverage statistics before")), ToolInput(tag="in_cover_min_percentage", input_type=Int(optional=True), prefix="--cover-min-percentage", doc=InputDocumentation(doc="Minimum percentage of coverage for tests to pass\n[NOSE_COVER_MIN_PERCENTAGE]")), ToolInput(tag="in_cover_inclusive", input_type=Boolean(optional=True), prefix="--cover-inclusive", doc=InputDocumentation(doc="Include all python files under working directory in\ncoverage report.  Useful for discovering holes in test\ncoverage if not all files are imported by the test\nsuite. [NOSE_COVER_INCLUSIVE]")), ToolInput(tag="in_cover_html", input_type=Boolean(optional=True), prefix="--cover-html", doc=InputDocumentation(doc="Produce HTML coverage information")), ToolInput(tag="in_cover_html_dir", input_type=String(optional=True), prefix="--cover-html-dir", doc=InputDocumentation(doc="Produce HTML coverage information in dir")), ToolInput(tag="in_cover_branches", input_type=Boolean(optional=True), prefix="--cover-branches", doc=InputDocumentation(doc="Include branch coverage in coverage report\n[NOSE_COVER_BRANCHES]")), ToolInput(tag="in_cover_xml", input_type=Boolean(optional=True), prefix="--cover-xml", doc=InputDocumentation(doc="Produce XML coverage information")), ToolInput(tag="in_cover_xml_file", input_type=File(optional=True), prefix="--cover-xml-file", doc=InputDocumentation(doc="Produce XML coverage information in file")), ToolInput(tag="in_pdb", input_type=Boolean(optional=True), prefix="--pdb", doc=InputDocumentation(doc="Drop into debugger on failures or errors")), ToolInput(tag="in_pdb_failures", input_type=Boolean(optional=True), prefix="--pdb-failures", doc=InputDocumentation(doc="Drop into debugger on failures")), ToolInput(tag="in_pdb_errors", input_type=Boolean(optional=True), prefix="--pdb-errors", doc=InputDocumentation(doc="Drop into debugger on errors")), ToolInput(tag="in_no_deprecated", input_type=Boolean(optional=True), prefix="--no-deprecated", doc=InputDocumentation(doc="Disable special handling of DeprecatedTest exceptions.")), ToolInput(tag="in_with_doctest", input_type=Boolean(optional=True), prefix="--with-doctest", doc=InputDocumentation(doc="Enable plugin Doctest:  Activate doctest plugin to\nfind and run doctests in non-test modules.\n[NOSE_WITH_DOCTEST]")), ToolInput(tag="in_doctest_tests", input_type=Boolean(optional=True), prefix="--doctest-tests", doc=InputDocumentation(doc="Also look for doctests in test modules. Note that\nclasses, methods and functions should have either\ndoctests or non-doctest tests, not both.\n[NOSE_DOCTEST_TESTS]")), ToolInput(tag="in_doctest_extension", input_type=String(optional=True), prefix="--doctest-extension", doc=InputDocumentation(doc="Also look for doctests in files with this extension\n[NOSE_DOCTEST_EXTENSION]")), ToolInput(tag="in_doctest_result_variable", input_type=String(optional=True), prefix="--doctest-result-variable", doc=InputDocumentation(doc="Change the variable name set to the result of the last\ninterpreter command from the default '_'. Can be used\nto avoid conflicts with the _() function used for text\ntranslation. [NOSE_DOCTEST_RESULT_VAR]")), ToolInput(tag="in_doctest_fixtures", input_type=File(optional=True), prefix="--doctest-fixtures", doc=InputDocumentation(doc="Find fixtures for a doctest file in module with this\nname appended to the base name of the doctest file")), ToolInput(tag="in_doctest_options", input_type=String(optional=True), prefix="--doctest-options", doc=InputDocumentation(doc="Specify options to pass to doctest. Eg.\n'+ELLIPSIS,+NORMALIZE_WHITESPACE'")), ToolInput(tag="in_with_isolation", input_type=Boolean(optional=True), prefix="--with-isolation", doc=InputDocumentation(doc="Enable plugin IsolationPlugin:  Activate the isolation\nplugin to isolate changes to external modules to a\nsingle test module or package. The isolation plugin\nresets the contents of sys.modules after each test\nmodule or package runs to its state before the test.\nPLEASE NOTE that this plugin should not be used with\nthe coverage plugin, or in any other case where module\nreloading may produce undesirable side-effects.\n[NOSE_WITH_ISOLATION]")), ToolInput(tag="in_detailed_errors", input_type=Boolean(optional=True), prefix="--detailed-errors", doc=InputDocumentation(doc="Add detail to error output by attempting to evaluate\nfailed asserts [NOSE_DETAILED_ERRORS]")), ToolInput(tag="in_with_profile", input_type=Boolean(optional=True), prefix="--with-profile", doc=InputDocumentation(doc="Enable plugin Profile:  Use this plugin to run tests\nusing the hotshot profiler.   [NOSE_WITH_PROFILE]")), ToolInput(tag="in_profile_sort", input_type=String(optional=True), prefix="--profile-sort", doc=InputDocumentation(doc="Set sort order for profiler output")), ToolInput(tag="in_profile_stats_file", input_type=File(optional=True), prefix="--profile-stats-file", doc=InputDocumentation(doc="Profiler stats file; default is a new temp file on\neach run")), ToolInput(tag="in_profile_restrict", input_type=String(optional=True), prefix="--profile-restrict", doc=InputDocumentation(doc="Restrict profiler output. See help for pstats.Stats\nfor details")), ToolInput(tag="in_no_skip", input_type=Boolean(optional=True), prefix="--no-skip", doc=InputDocumentation(doc="Disable special handling of SkipTest exceptions.")), ToolInput(tag="in_with_id", input_type=Boolean(optional=True), prefix="--with-id", doc=InputDocumentation(doc="Enable plugin TestId:  Activate to add a test id (like\n#1) to each test name output. Activate with --failed\nto rerun failing tests only.  [NOSE_WITH_ID]")), ToolInput(tag="in_id_file", input_type=File(optional=True), prefix="--id-file", doc=InputDocumentation(doc="Store test ids found in test runs in this file.\nDefault is the file .noseids in the working directory.")), ToolInput(tag="in_failed", input_type=Boolean(optional=True), prefix="--failed", doc=InputDocumentation(doc="Run the tests that failed in the last test run.")), ToolInput(tag="in_processes", input_type=Int(optional=True), prefix="--processes", doc=InputDocumentation(doc="Spread test run among this many processes. Set a\nnumber equal to the number of processors or cores in\nyour machine for best results. Pass a negative number\nto have the number of processes automatically set to\nthe number of cores. Passing 0 means to disable\nparallel testing. Default is 0 unless NOSE_PROCESSES\nis set. [NOSE_PROCESSES]")), ToolInput(tag="in_process_timeout", input_type=Int(optional=True), prefix="--process-timeout", doc=InputDocumentation(doc="Set timeout for return of results from each test\nrunner process. Default is 10. [NOSE_PROCESS_TIMEOUT]")), ToolInput(tag="in_process_restart_worker", input_type=Boolean(optional=True), prefix="--process-restartworker", doc=InputDocumentation(doc="If set, will restart each worker process once their\ntests are done, this helps control memory leaks from\nkilling the system. [NOSE_PROCESS_RESTARTWORKER]")), ToolInput(tag="in_with_x_unit", input_type=Boolean(optional=True), prefix="--with-xunit", doc=InputDocumentation(doc="Enable plugin Xunit: This plugin provides test results\nin the standard XUnit XML format. [NOSE_WITH_XUNIT]")), ToolInput(tag="in_x_unit_file", input_type=File(optional=True), prefix="--xunit-file", doc=InputDocumentation(doc="Path to xml file to store the xunit report in. Default\nis nosetests.xml in the working directory\n[NOSE_XUNIT_FILE]")), ToolInput(tag="in_x_unit_testsuite_name", input_type=String(optional=True), prefix="--xunit-testsuite-name", doc=InputDocumentation(doc="Name of the testsuite in the xunit xml, generated by\nplugin. Default test suite name is nosetests.")), ToolInput(tag="in_all_modules", input_type=Boolean(optional=True), prefix="--all-modules", doc=InputDocumentation(doc="Enable plugin AllModules: Collect tests from all\npython modules.  [NOSE_ALL_MODULES]")), ToolInput(tag="in_collect_only", input_type=Boolean(optional=True), prefix="--collect-only", doc=InputDocumentation(doc="Enable collect-only:  Collect and output test names\nonly, don't run any tests.  [COLLECT_ONLY]\n")), ToolInput(tag="in_package", input_type=String(), position=0, doc=InputDocumentation(doc="--first-package-wins, --first-pkg-wins, --1st-pkg-wins")), ToolInput(tag="in_behavior_dot", input_type=String(), position=0, doc=InputDocumentation(doc="--no-byte-compile     Prevent nose from byte-compiling the source into .pyc")), ToolInput(tag="in_run", input_type=String(), position=0, doc=InputDocumentation(doc="--cover-tests         Include test modules in coverage report"))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Nosetests_2_7_V0_1_0().translate("wdl", allow_empty_container=True)

